﻿/**
* ******************************************************
*                                                       *
*   Copyright (C) Microsoft. All rights reserved.       *
*                                                       *
*******************************************************
*/
/// <reference path="../typings/node.d.ts" />
/// <reference path="../typings/Q.d.ts" />
/// <reference path="../typings/vcremote-utils.d.ts" />
/// <reference path="../typings/express.d.ts" />
/// <reference path="../typings/semver.d.ts" />
"use strict";
var projects = require("./projectsystem/project-collection");
var project = require("./projectsystem/project");
var build = require("./projectsystem/build");

var fs = require("fs");

var xmlbuilder = require("xmlbuilder");

var VCRemoteLib;
(function (VCRemoteLib) {
    var VCLanguageSpecificsResponse = (function () {
        function VCLanguageSpecificsResponse(projects, request) {
            this._projects = projects;
            this._request = request;
        }
        VCLanguageSpecificsResponse.prototype.renderProjects = function (res) {
            res.send(200, xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[0 /* SUCCESS */]).up().ele("code", projects.ProjectCollectionError[0 /* OK */]).up().end({ pretty: true }));
        };

        VCLanguageSpecificsResponse.prototype.renderIncompatibleClient = function (res) {
            res.send(200, xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[1 /* FAILURE */]).up().ele("code", projects.ProjectCollectionError[1 /* INCOMPATIBLE */]).up().ele("message", "The client is incompatible with current version of this build agent.").up().end({ pretty: true }));
        };

        VCLanguageSpecificsResponse.prototype.renderProjectInfo = function (res, prj) {
            var stateHistory = prj.history.map(function (e) {
                return project.ProjectState[e];
            }).reduce(function (prev, curr) {
                return prev + "," + curr;
            });
            res.send(200, xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[0 /* SUCCESS */]).up().ele("code", projects.ProjectCollectionError[0 /* OK */]).up().ele("storeDirectory", this._projects.storeDirectory).up().ele("project", { id: prj.id }).ele("projectDirectory", prj.directory).up().ele("state", project.ProjectState[prj.state]).up().ele("stateHistory", stateHistory).up().end({ pretty: true }));
        };

        VCLanguageSpecificsResponse.prototype.renderProjectCfg = function (res, cfg) {
            res.send(xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[0 /* SUCCESS */]).up().ele("code", projects.ProjectCollectionError[0 /* OK */]).up().ele("storeDirectory", this._projects.storeDirectory).up().ele("project", { id: cfg.project.id }).ele("projectDirectory", cfg.project.directory).up().ele("configuration", { id: cfg.id }).ele("outputDirectory", cfg.outputDirectory).up().ele("name", cfg.config).up().ele("arch", cfg.arch).up().ele("sdk", cfg.sdk).up().end({ pretty: true }));
        };

        VCLanguageSpecificsResponse.prototype.renderProjectCfgs = function (res, prj) {
            res.writeHead(200, "OK", { 'Content-Type': 'text/xml' });
            var project = xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[0 /* SUCCESS */]).up().ele("code", projects.ProjectCollectionError[0 /* OK */]).up().ele("storeDirectory", this._projects.storeDirectory).up().ele("project", { id: prj.id }).ele("projectDirectory", prj.directory).up();
            var cfgs = prj.build.all;
            for (var i = 0; i < cfgs.length; i++) {
                project.ele("configuration", { id: cfgs[i] }).ele("outputDirectory", cfgs[i].outputDirectory).up().ele("logFileName", cfgs[i].logFileName).up().ele("name", cfgs[i].config.config).up().ele("arch", cfgs[i].config.arch).up().ele("sdk", cfgs[i].config.sdk).up().ele("build").ele("state", build.BuildState[cfgs[i].state]);
            }
            res.write(project.end({ pretty: true }));
            res.end();
        };

        VCLanguageSpecificsResponse.prototype.renderBuildInfo = function (res, bld) {
            res.writeHead(200, "OK", { 'Content-Type': 'text/xml' });
            res.write(xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[0 /* SUCCESS */]).up().ele("code", projects.ProjectCollectionError[0 /* OK */]).up().ele("storeDirectory", this._projects.storeDirectory).up().ele("project", { id: bld.project.id }).ele("projectDirectory", bld.project.directory).up().ele("configuration", { id: bld.config.id }).ele("outputDirectory", bld.outputDirectory).up().ele("logFileName", bld.logFileName).up().ele("name", bld.config.config).up().ele("arch", bld.config.arch).up().ele("sdk", bld.config.arch).up().ele("build").ele("state", build.BuildState[bld.state]).up().ele("result", build.BuildResult[bld.result]).up().up().end({ pretty: true }));
            res.end();
        };

        VCLanguageSpecificsResponse.prototype.renderBuild = function (res, bld) {
            res.writeHead(200, "OK", {
                "Content-Type": "application/zip",
                "Content-Length": fs.statSync(bld.archiveFileName).size
            });
            fs.createReadStream(bld.archiveFileName).pipe(res);
        };

        VCLanguageSpecificsResponse.prototype.renderBuildLog = function (res, bld, log, pos) {
            res.writeHead(200, "OK", { "Content-Type": "text/xml" });
            res.write(xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[0 /* SUCCESS */]).up().ele("code", projects.ProjectCollectionError[0 /* OK */]).up().ele("storeDirectory", this._projects.storeDirectory).up().ele("project", { id: bld.project.id }).ele("projectDirectory", bld.project.directory).up().ele("configuration", { id: bld.id }).ele("outputDirectory", bld.outputDirectory).up().ele("logFileName", bld.logFileName).up().ele("name", bld.config.config).up().ele("arch", bld.config.arch).up().ele("sdk", bld.config.sdk).up().ele("build").ele("state", build.BuildState[bld.state]).up().ele("result", build.BuildResult[bld.result]).up().ele("log", { pos: pos, length: log.length, available: bld.log.size }).dat(log).up().up().end({ pretty: true }));
            res.end();
        };

        VCLanguageSpecificsResponse.prototype.renderBuildStatus = function (res, prj, bld) {
            res.writeHead(200, "OK", { "Content-Type": "text/xml" });
            var project = xmlbuilder.create("projectCollection").ele("version", this._projects.version).up().ele("minimumSupportedClientVersion", this._projects.minimumSupportedClientVersion).up().ele("maximumSupportedClientVersion", this._projects.maximumSupportedClientVersion).up().ele("status", projects.ProjectCollectionStatus[0 /* SUCCESS */]).up().ele("code", projects.ProjectCollectionError[0 /* OK */]).up().ele("storeDirectory", this._projects.storeDirectory).up().ele("project", { id: prj.id }).ele("projectDirectory", prj.directory).up();
            if (bld) {
                // convert enum array to string array and generate a enum1,emum2... string
                var stateHistory = bld.history.map(function (e) {
                    return build.BuildState[e];
                }).reduce(function (prev, curr) {
                    return prev + "," + curr;
                });
                project.ele("configuration", { id: bld.id }).ele("outputDirectory", bld.outputDirectory).up().ele("logFileName", bld.logFileName).up().ele("name", bld.config.config).up().ele("arch", bld.config.arch).up().ele("sdk", bld.config.sdk).up().ele("build").ele("state", build.BuildState[bld.state]).up().ele("result", build.BuildResult[bld.result]).up().ele("stateHistory", stateHistory).up().up();
            }
            res.write(project.end({ pretty: true }));
            res.end();
        };
        return VCLanguageSpecificsResponse;
    })();
    VCRemoteLib.VCLanguageSpecificsResponse = VCLanguageSpecificsResponse;
})(VCRemoteLib || (VCRemoteLib = {}));

module.exports = VCRemoteLib;
